@@ -24,7 +24,7 @@ class JinjaEnvironment(Environment):
                    'for':['empty'], 
                    'with':['with']}
 
-    code_tags = ('for','block','if','else','elif','filter','with','while','set')
+    code_tags = ('include','extends','for','block','if','else','elif','filter','with','while','set')
 
     def tag_begin(self,node):
         return '{%%%s%%}'%node.statement
